# more-polars-utils

Utility functions for [polars](https://pola.rs/)

This library expands the [polars.DataFrame](https://docs.pola.rs/api/python/stable/reference/dataframe/index.html) with utility functions for common data engineering operations. This collection of generic utility functions aims to improve the readability and maintainability of Polars-based projects.

## Installation

```bash
pip install more-polars-utils
```
